import pandas as pd
from sklearn.model_selection import train_test_split
from sklearn.metrics import mean_squared_error
from sklearn.linear_model import Ridge, RidgeCV
import numpy as np

# Load the dataset and preprocess
data = pd.read_csv('c:/users/hjhjhj/desktop/shell.csv')
data['STATUS_BINARY'] = data['STATUS_CONF'].apply(lambda x: 1 if x == "validated" else 0)
data_dummies = pd.get_dummies(data.drop(columns=['STATUS_CONF', 'IP_INFO']), drop_first=True)
X = data_dummies.drop('STATUS_BINARY', axis=1)
y = data_dummies['STATUS_BINARY']
X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.2, random_state=42)

# RidgeCV: Ridge regression with built-in cross-validation to find the best alpha
ridge_cv = RidgeCV(alphas=np.logspace(-6, 6, 13), store_cv_values=True)
ridge_cv.fit(X_train, y_train)

# Using the best alpha found by RidgeCV to make predictions
ridge_model = Ridge(alpha=ridge_cv.alpha_)
ridge_model.fit(X_train, y_train)
ridge_y_pred = ridge_model.predict(X_test)
ridge_mse = mean_squared_error(y_test, ridge_y_pred)

# Print the results
print(f"Optimal alpha for Ridge regression: {ridge_cv.alpha_}")
print(f"MSE for the test set using Ridge regression: {ridge_mse:.6f}")
